/* $Workfile: Dsp54LawsCst.c $   $Revision: 1 $    $Modtime: 5/19/03 3:03p $  */
/*--------------------------------------------------------------------------*\

  Odin TeleSystems Inc.

  SAA-1007-1 OTX DSP C54x Software Development Kit (SDK)

  Dsp54LawsCst

  Implementation of G.711 A-law and U-law functions for the 54CST device.

\*--------------------------------------------------------------------------*/

#ifndef CHIP_54CST 
  xxxx  // to prevent compilation for other devices other than 54CST 
#endif

// Defines CST channel structure.
// Defines a global variable Ch0 to be used for single channel applications.
// This channel is also a reference address for S-register description.
#include "Framework\CSTChannel.h"

#include "G726g711\g726g711.h"
#include "G726g711\ig726g711.h"
#include "G726g711\g726g711_spcorp.h"


#include "Dsp54Api.h"


/*--------------------------------------------------------------------------*\
  Macros
\*--------------------------------------------------------------------------*/

/*--------------------------------------------------------------------------*\
  Private data
\*--------------------------------------------------------------------------*/


static G726G711_Handle g_hG711AlawCodec;
static G726G711_Handle g_hG711UlawCodec;


/*--------------------------------------------------------------------------*\
  Function Prototypes
\*--------------------------------------------------------------------------*/

/*--------------------------------------------------------------------------*\
  @func
\*--------------------------------------------------------------------------*/
short OtxDspLawInit(void) 
{
  
  G726G711_Params params;
  //G726G711_Status  status;
  
  params.rate = IG726G711_64KBPS;
  params.law  = IG726G711_ALAW;
  g_hG711AlawCodec = G726G711_create(&G726G711_SPCORP_IG726G711, &params);
  
  params.rate = IG726G711_64KBPS;
  params.law  = IG726G711_ULAW;
  g_hG711UlawCodec = G726G711_create(&G726G711_SPCORP_IG726G711, &params);
  //status = G726G711_getStatus(g_hG711Codec);
 
  return OTXDSP_SDK_S_OK;
}




/*--------------------------------------------------------------------------*\
  @func
\*--------------------------------------------------------------------------*/
short OtxDspAlawCompress(
  short lawCompInput  /* @parm 14 bit 2-s complement value to be companded */
)
{
  XDAS_Int16 output;
  G726G711_encode(g_hG711AlawCodec, (XDAS_Int16 *)&lawCompInput, &output, 1);
  return (short) output;
}

/*--------------------------------------------------------------------------*\
  @func
\*--------------------------------------------------------------------------*/
short OtxDspUlawCompress(
  short lawCompInput  /* @parm 14 bit 2-s complement value to be companded */
)
{
  XDAS_Int16 output;
  G726G711_encode(g_hG711UlawCodec, (XDAS_Int16 *)&lawCompInput, &output, 1);
  return (short) output;
}

/*--------------------------------------------------------------------------*\
  @func
\*--------------------------------------------------------------------------*/
short OtxDspLawExpand(
  short lawExpandInput,    /* @parm Sample to be expanded (8-bits sign magnitude value */
  short law                /* @parm Law (0 = u-law, 1 = A-law) */
)
{
  XDAS_Int16 output;
  G726G711_decode(law ? g_hG711AlawCodec : g_hG711UlawCodec, (XDAS_Int16 *)&lawExpandInput, &output, 1);
  return (short) output;
}


